==> scala_2.5.0.orig.tar.gz: scala-2.5.0-final/src/library/scala/collection/jcl/SortedSetWrapper.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2006-2007, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: SortedSetWrapper.scala 10782 2007-04-22 02:46:34Z mcdirmid $

package scala.collection.jcl;

/** <p>
 *    A wrapper around a Java sorted set.
 *  </p>
 *  <p>
 *    The comparator of the sorted set matches the comparator of this set. 
 *  </p>
 *
 *  @author Sean McDirmid
 */
trait SortedSetWrapper[A] extends SortedSet[A] with SetWrapper[A] {
  protected def underlying : java.util.SortedSet;
  /** delegates to the comparator of the underlying Java sorted set */
  override def compare(a0 : A, a1 : A) = underlying.comparator.compare(a0, a1);
  override def first = underlying.first.asInstanceOf[A];
  override def last  = underlying.last .asInstanceOf[A];
  override def rangeImpl(from : Option[A], until : Option[A]) : SortedSet[A] = new Range(from,until);
  protected class Range(from : Option[A], until : Option[A]) extends super.Range(from, until) with SortedSetWrapper[A] {
    val underlying = Tuple2(from,until) match {
    case Tuple2(None,Some(until)) => SortedSetWrapper.this.underlying.headSet(until);
    case Tuple2(Some(from),None)  => SortedSetWrapper.this.underlying.tailSet(from);
    case Tuple2(Some(from),Some(until)) => SortedSetWrapper.this.underlying.subSet(from,until);
    case _ => throw new IllegalArgumentException;
    }
    override def elements : MutableIterator[A] = super[SortedSetWrapper].elements;
  }
  override def toString = super.toString;
}

==> scala_2.6.1.orig.tar.gz: scala-2.6.1-final/src/library/scala/collection/jcl/SortedSetWrapper.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2006-2007, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: SortedSetWrapper.scala 11110 2007-05-21 12:40:17Z mcdirmid $

package scala.collection.jcl;

/** <p>
 *    A wrapper around a Java sorted set.
 *  </p>
 *  <p>
 *    The comparator of the sorted set matches the comparator of this set. 
 *  </p>
 *
 *  @author Sean McDirmid
 */
trait SortedSetWrapper[A] extends SortedSet[A] with SetWrapper[A] {
  def underlying : java.util.SortedSet;
  /** delegates to the comparator of the underlying Java sorted set */
  override def compare(a0 : A, a1 : A) = underlying.comparator.compare(a0, a1);
  override def firstKey = underlying.first.asInstanceOf[A];
  override def lastKey  = underlying.last .asInstanceOf[A];
  override def rangeImpl(from : Option[A], until : Option[A]) : SortedSet[A] = new Range(from,until);
  protected class Range(from : Option[A], until : Option[A]) extends super.Range(from, until) with SortedSetWrapper[A] {
    val underlying = Tuple2(from,until) match {
    case Tuple2(None,Some(until)) => SortedSetWrapper.this.underlying.headSet(until);
    case Tuple2(Some(from),None)  => SortedSetWrapper.this.underlying.tailSet(from);
    case Tuple2(Some(from),Some(until)) => SortedSetWrapper.this.underlying.subSet(from,until);
    case _ => throw new IllegalArgumentException;
    }
    override def elements : MutableIterator[A] = super[SortedSetWrapper].elements;
  }
  override def toString = super.toString;
}
